@@ -4,6 +4,7 @@ from opyoid.injection_state import InjectionState
 from opyoid.provider import Provider
 from opyoid.typings import InjectedT
 from .binding import Binding
+from .registered_binding import RegisteredBinding
 
 BindingT = TypeVar("BindingT", bound=Binding)
 
@@ -15,6 +16,6 @@ class BindingToProviderAdapter(Generic[BindingT]):
         """Return True if this adapter can handle this binding."""
         raise NotImplementedError
 
-    def create(self, binding: BindingT, state: InjectionState) -> Provider[InjectedT]:
+    def create(self, binding: RegisteredBinding[BindingT], state: InjectionState) -> Provider[InjectedT]:
         """Returns a provider corresponding to this binding."""
         raise NotImplementedError
