@@ -1,5 +1,7 @@
 from typing import Set
 
+from opyoid.frozen_target import FrozenTarget
+from opyoid.typings import InjectedT
 from .abstract_module import AbstractModule
 from .registered_binding import RegisteredBinding
 
@@ -7,14 +9,14 @@ from .registered_binding import RegisteredBinding
 class PrivateModule(AbstractModule):
     def __init__(self):
         AbstractModule.__init__(self)
-        self._exposed_bindings: Set[RegisteredBinding] = set()
+        self._exposed_bindings: Set[FrozenTarget] = set()
 
     def configure(self) -> None:
         raise NotImplementedError
 
-    def is_exposed(self, binding: RegisteredBinding) -> bool:
-        return binding in self._exposed_bindings
+    def is_exposed(self, target: FrozenTarget[InjectedT]) -> bool:
+        return target in self._exposed_bindings
 
     def expose(self, *bindings: RegisteredBinding) -> None:
         for binding in bindings:
-            self._exposed_bindings.add(binding)
+            self._exposed_bindings.add(binding.target)
